NormalInputAndMarkWidget class

Inheritance

Constructors

NormalInputAndMarkWidget({Key? key, Color backgroundColor = Colors.white, double space = 20, EdgeInsets padding = const EdgeInsets.symmetric(vertical: 16), bool isRequired = false, double requiredIndent = 0, bool marked = false, Color markLineColor = const Color(0xFFE51C23), Color normalLineColor = const Color(0xFFF3F4F7), double? lineIndent, double? lineEndIndent, bool showErrorTips = false, String errorTipsText = '', CrossAxisAlignment contentCrossAxisAlignment = CrossAxisAlignment.center, required Widget left, required Widget right, Widget? errorTips})
const

Properties

backgroundColor → Color
final
contentCrossAxisAlignment → CrossAxisAlignment
final
errorTips → Widget?
final
errorTipsText → String
final
hashCode → int
The hash code for this object.
no setterinherited
isRequired → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
left → Widget
final
lineEndIndent → double?
final
lineIndent → double?
final
marked → bool
final
markLineColor → Color
final
normalLineColor → Color
final
padding → EdgeInsets
final
requiredIndent → double
final
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showErrorTips → bool
final
space → double
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited